@@ -1,25 +1,3 @@
-/*
-
-Copyright (C) 1996, 1997, 1999, 2000, 2003, 2005, 2007 John W. Eaton
-
-This file is part of Octave.
-
-Octave is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 3 of the License, or (at your
-option) any later version.
-
-Octave is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<http://www.gnu.org/licenses/>.
-
-*/
-
 #include <octave/config.h>
 
 #include <cstdlib>
@@ -47,7 +25,6 @@ along with Octave; see the file COPYING.  If not, see
 #include <octave/symtab.h>
 #include <octave/variables.h>
 
-class Octave_map;
 class octave_value_list;
 
 class tree_walker;
@@ -263,10 +240,10 @@ Creates an integer variable from VAL.")
   if (! type_loaded)
     {
       octave_integer::register_type ();
-      mlock ("make_int");
+      mlock ();
 
       octave_stdout << "installing integer type at type-id = "
-	   << octave_integer::static_type_id () << "\n";
+           << octave_integer::static_type_id () << "\n";
 
       INSTALL_UNOP (op_not, octave_integer, gnot);
       INSTALL_UNOP (op_uminus, octave_integer, uminus);
@@ -303,7 +280,7 @@ Creates an integer variable from VAL.")
       double d = args(0).double_value ();
 
       if (! error_state)
-	retval = octave_value (new octave_integer (NINT (d)));
+        retval = octave_value (new octave_integer (NINT (d)));
     }
   else
     usage ("make_int");
@@ -337,9 +314,3 @@ DEFUN_DLD (doit, args, ,
 DEFINE_OCTAVE_ALLOCATOR (octave_integer);
 
 DEFINE_OV_TYPEID_FUNCTIONS_AND_DATA (octave_integer, "integer", "integer");
-
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
