@@ -1,8 +1,8 @@
 // Template array classes
 /*
 
-Copyright (C) 1996, 1997, 1999, 2000, 2002, 2003, 2004, 2005, 2007,
-              2008, 2009 John W. Eaton
+Copyright (C) 1996-2011 John W. Eaton
+Copyright (C) 2010 VZLU Prague
 
 This file is part of Octave.
 
@@ -37,31 +37,13 @@ along with Octave; see the file COPYING.  If not, see
 #include "lo-error.h"
 
 template <class T>
-const typename DiagArray2<T>::Proxy& 
-DiagArray2<T>::Proxy::operator = (const T& val) const
+DiagArray2<T>::DiagArray2 (const Array<T>& a, octave_idx_type r,
+                           octave_idx_type c)
+  : Array<T> (a.as_column ()), d1 (r), d2 (c)
 {
-  if (i == j)
-    {
-      if (object)
-        object->set (val, i);
-    }
-  else
-    (*current_liboctave_error_handler)
-      ("invalid assignment to off-diagonal in diagonal array");
-
-  return *this;
-}
-
-template <class T>
-DiagArray2<T>::Proxy::operator T () const
-{
-  if (object && i == j)
-    return object->get (i);
-  else
-    {
-      static T foo;
-      return foo;
-    }
+  octave_idx_type rcmin = std::min (r, c);
+  if (rcmin != a.length ())
+    Array<T>::resize (dim_vector (rcmin, 1));
 }
 
 template <class T>
@@ -74,9 +56,9 @@ DiagArray2<T>::diag (octave_idx_type k) const
     // The main diagonal is shallow-copied.
     d = *this;
   else if (k > 0 && k < cols ())
-    d = Array<T> (std::min (cols () - k, rows ()), T ());
+    d = Array<T> (dim_vector (std::min (cols () - k, rows ()), 1), T ());
   else if (k < 0 && -k < rows ())
-    d = Array<T> (std::min (rows () + k, cols ()), T ());
+    d = Array<T> (dim_vector (std::min (rows () + k, cols ()), 1), T ());
   else
     (*current_liboctave_error_handler)
       ("diag: requested diagonal out of range");
@@ -88,22 +70,14 @@ template <class T>
 DiagArray2<T>
 DiagArray2<T>::transpose (void) const
 {
-  DiagArray2<T> retval (*this);
-  retval.d1 = d2;
-  retval.d2 = d1;
-  return retval;
+  return DiagArray2<T> (*this, d2, d1);
 }
 
 template <class T>
 DiagArray2<T>
 DiagArray2<T>::hermitian (T (* fcn) (const T&)) const
 {
-  DiagArray2<T> retval (dim2 (), dim1 ());
-  const T *p = this->data ();
-  T *q = retval.fortran_vec ();
-  for (octave_idx_type i = 0; i < this->length (); i++)
-    q [i] = fcn (p [i]);
-  return retval;
+  return DiagArray2<T> (Array<T>::template map<T> (fcn), d2, d1);
 }
 
 // A two-dimensional array with diagonal elements only.
@@ -112,30 +86,18 @@ template <class T>
 T
 DiagArray2<T>::checkelem (octave_idx_type r, octave_idx_type c) const
 {
-  if (r < 0 || c < 0 || r >= dim1 () || c >= dim2 ())
-    {
-      (*current_liboctave_error_handler) ("range error in DiagArray2");
-      return T ();
-    }
+  if (r < 0 || r >= dim1 ())
+    gripe_index_out_of_range (2, 1, r+1, dim1 ());
+  if (c < 0 || c >= dim2 ())
+    gripe_index_out_of_range (2, 2, c+1, dim2 ());
+
   return elem (r, c);
 }
 
-template <class T>
-typename DiagArray2<T>::Proxy
-DiagArray2<T>::checkelem (octave_idx_type r, octave_idx_type c) 
-{
-  if (r < 0 || c < 0 || r >= dim1 () || c >= dim2 ())
-    {
-      (*current_liboctave_error_handler) ("range error in DiagArray2");
-      return Proxy (0, r, c);
-    }
-  else
-    return Proxy (this, r, c);
-}
-
 template <class T>
 void
-DiagArray2<T>::resize (octave_idx_type r, octave_idx_type c)
+DiagArray2<T>::resize (octave_idx_type r, octave_idx_type c,
+                       const T& rfv)
 {
   if (r < 0 || c < 0)
     {
@@ -145,40 +107,19 @@ DiagArray2<T>::resize (octave_idx_type r, octave_idx_type c)
 
   if (r != dim1 () || c != dim2 ())
     {
-      Array<T>::resize (std::min (r, c));
+      Array<T>::resize (dim_vector (std::min (r, c), 1), rfv);
       d1 = r; d2 = c;
     }
 }
 
 template <class T>
-void
-DiagArray2<T>::resize_fill (octave_idx_type r, octave_idx_type c, const T& val)
+Array<T>
+DiagArray2<T>::array_value (void) const
 {
-  if (r < 0 || c < 0)
-    {
-      (*current_liboctave_error_handler) ("can't resize to negative dimensions");
-      return;
-    }
+  Array<T> result (dims (), T (0));
 
-  if (r != dim1 () || c != dim2 ())
-    {
-      Array<T>::resize_fill (std::min (r, c), val);
-      d1 = r; d2 = c;
-    }
-}
-
-template <class T>
-DiagArray2<T>::operator Array2<T> (void) const
-{
-  Array2<T> result (dim1 (), dim2 ());
   for (octave_idx_type i = 0, len = length (); i < len; i++)
     result.xelem (i, i) = dgelem (i);
 
   return result;
 }
-
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
