@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996, 1997, 1998, 2004, 2005, 2006, 2007 John W. Eaton
+Copyright (C) 1996-2011 John W. Eaton
 
 This file is part of Octave.
 
@@ -40,7 +40,7 @@ template <int n>
 void
 swap_bytes (volatile void *ptr)
 {
-  for (size_t i = 0; i < n/2; i++)
+  for (int i = 0; i < n/2; i++)
     swap_bytes (ptr, i, n-1-i);
 }
 
@@ -95,9 +95,3 @@ swap_bytes<1> (volatile void *, int)
 }
 
 #endif
-
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
