@@ -1,13 +1,13 @@
 /*
 
-Copyright (C) 1996, 1997 John W. Eaton
+Copyright (C) 1994-2011 John W. Eaton
 
 This file is part of Octave.
 
 Octave is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2, or (at your option) any
-later version.
+Free Software Foundation; either version 3 of the License, or (at your
+option) any later version.
 
 Octave is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -15,39 +15,53 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, write to the Free
-Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-02110-1301, USA.
+along with Octave; see the file COPYING.  If not, see
+<http://www.gnu.org/licenses/>.
 
 */
 
 #if !defined (octave_Matrix_int_h)
 #define octave_Matrix_int_h 1
 
-#include "MArray2.h"
+#include "MArray.h"
 #include "MDiagArray2.h"
 #include "MatrixType.h"
 
 #include "mx-defs.h"
-#include "mx-op-defs.h"
+#include "mx-op-decl.h"
+#include "DET.h"
 
 class
 OCTAVE_API
-Matrix : public MArray2<double>
+Matrix : public MArray<double>
 {
 public:
 
-  typedef void (*solve_singularity_handler) (double rcond);
+  typedef ColumnVector column_vector_type;
+  typedef RowVector row_vector_type;
 
-  Matrix (void) : MArray2<double> () { }
+  typedef void (*solve_singularity_handler) (double rcon);
 
-  Matrix (octave_idx_type r, octave_idx_type c) : MArray2<double> (r, c) { }
+  Matrix (void) : MArray<double> () { }
 
-  Matrix (octave_idx_type r, octave_idx_type c, double val) : MArray2<double> (r, c, val) { }
+  Matrix (octave_idx_type r, octave_idx_type c)
+    : MArray<double> (dim_vector (r, c)) { }
 
-  Matrix (const Matrix& a) : MArray2<double> (a) { }
+  Matrix (octave_idx_type r, octave_idx_type c, double val)
+    : MArray<double> (dim_vector (r, c), val) { }
 
-  Matrix (const MArray2<double>& a) : MArray2<double> (a) { }
+  Matrix (const dim_vector& dv) : MArray<double> (dv.redim (2)) { }
+
+  Matrix (const dim_vector& dv, double val)
+    : MArray<double> (dv.redim (2), val) { }
+
+  Matrix (const Matrix& a) : MArray<double> (a) { }
+
+  template <class U>
+  Matrix (const MArray<U>& a) : MArray<double> (a.as_matrix ()) { }
+
+  template <class U>
+  Matrix (const Array<U>& a) : MArray<double> (a.as_matrix ()) { }
 
   explicit Matrix (const RowVector& rv);
 
@@ -55,13 +69,15 @@ public:
 
   explicit Matrix (const DiagMatrix& a);
 
+  explicit Matrix (const PermMatrix& a);
+
   explicit Matrix (const boolMatrix& a);
 
   explicit Matrix (const charMatrix& a);
 
   Matrix& operator = (const Matrix& a)
     {
-      MArray2<double>::operator = (a);
+      MArray<double>::operator = (a);
       return *this;
     }
 
@@ -93,7 +109,9 @@ public:
   friend OCTAVE_API Matrix real (const ComplexMatrix& a);
   friend OCTAVE_API Matrix imag (const ComplexMatrix& a);
 
-  Matrix transpose (void) const { return MArray2<double>::transpose (); }
+  friend class ComplexMatrix;
+
+  Matrix transpose (void) const { return MArray<double>::transpose (); }
 
   // resize is the destructive equivalent for this one
 
@@ -107,23 +125,29 @@ public:
 
   ColumnVector column (octave_idx_type i) const;
 
-private:
-  Matrix tinverse (MatrixType &mattype, octave_idx_type& info, double& rcond, 
-		   int force, int calc_cond) const;
+  void resize (octave_idx_type nr, octave_idx_type nc,
+               double rfv = resize_fill_value ())
+  {
+    MArray<double>::resize (dim_vector (nr, nc), rfv);
+  }
 
-  Matrix finverse (MatrixType &mattype, octave_idx_type& info, double& rcond, 
-		   int force, int calc_cond) const;
+private:
+  Matrix tinverse (MatrixType &mattype, octave_idx_type& info, double& rcon,
+                   int force, int calc_cond) const;
+
+  Matrix finverse (MatrixType &mattype, octave_idx_type& info, double& rcon,
+                   int force, int calc_cond) const;
 
 public:
   Matrix inverse (void) const;
   Matrix inverse (octave_idx_type& info) const;
-  Matrix inverse (octave_idx_type& info, double& rcond, int force = 0,
-		  int calc_cond = 1) const;
+  Matrix inverse (octave_idx_type& info, double& rcon, int force = 0,
+                  int calc_cond = 1) const;
 
   Matrix inverse (MatrixType &mattype) const;
   Matrix inverse (MatrixType &mattype, octave_idx_type& info) const;
-  Matrix inverse (MatrixType &mattype, octave_idx_type& info, double& rcond,
-		  int force = 0, int calc_cond = 1) const;
+  Matrix inverse (MatrixType &mattype, octave_idx_type& info, double& rcon,
+                  int force = 0, int calc_cond = 1) const;
 
   Matrix pseudo_inverse (double tol = 0.0) const;
 
@@ -135,110 +159,132 @@ public:
 
   DET determinant (void) const;
   DET determinant (octave_idx_type& info) const;
-  DET determinant (octave_idx_type& info, double& rcond, int calc_cond = 1) const;
+  DET determinant (octave_idx_type& info, double& rcon, int calc_cond = 1) const;
+  DET determinant (MatrixType &mattype, octave_idx_type& info,
+                   double& rcon, int calc_cond = 1) const;
+
+  double rcond (void) const;
+  double rcond (MatrixType &mattype) const;
 
 private:
   // Upper triangular matrix solvers
   Matrix utsolve (MatrixType &typ, const Matrix& b, octave_idx_type& info,
-		  double& rcond, solve_singularity_handler sing_handler,
-		  bool calc_cond = false) const;
+                  double& rcon, solve_singularity_handler sing_handler,
+                  bool calc_cond = false, blas_trans_type transt = blas_no_trans) const;
 
   // Lower triangular matrix solvers
   Matrix ltsolve (MatrixType &typ, const Matrix& b, octave_idx_type& info,
-		  double& rcond, solve_singularity_handler sing_handler,
-		  bool calc_cond = false) const;
+                  double& rcon, solve_singularity_handler sing_handler,
+                  bool calc_cond = false, blas_trans_type transt = blas_no_trans) const;
 
   // Full matrix solvers (lu/cholesky)
   Matrix fsolve (MatrixType &typ, const Matrix& b, octave_idx_type& info,
-		 double& rcond, solve_singularity_handler sing_handler,
-		 bool calc_cond = false) const;
+                 double& rcon, solve_singularity_handler sing_handler,
+                 bool calc_cond = false) const;
 
 public:
   // Generic interface to solver with no probing of type
   Matrix solve (MatrixType &typ, const Matrix& b) const;
   Matrix solve (MatrixType &typ, const Matrix& b, octave_idx_type& info) const;
-  Matrix solve (MatrixType &typ, const Matrix& b, octave_idx_type& info, 
-		double& rcond) const;
   Matrix solve (MatrixType &typ, const Matrix& b, octave_idx_type& info,
-		double& rcond, solve_singularity_handler sing_handler,
-		bool singular_fallback = true) const;
+                double& rcon) const;
+  Matrix solve (MatrixType &typ, const Matrix& b, octave_idx_type& info,
+                double& rcon, solve_singularity_handler sing_handler,
+                bool singular_fallback = true, blas_trans_type transt = blas_no_trans) const;
 
   ComplexMatrix solve (MatrixType &typ, const ComplexMatrix& b) const;
-  ComplexMatrix solve (MatrixType &typ, const ComplexMatrix& b, 
-		       octave_idx_type& info) const;
-  ComplexMatrix solve (MatrixType &typ, const ComplexMatrix& b, 
-		       octave_idx_type& info, double& rcond) const;
-  ComplexMatrix solve (MatrixType &typ, const ComplexMatrix& b, 
-		       octave_idx_type& info, double& rcond,
-		       solve_singularity_handler sing_handler,
-		       bool singular_fallback = true) const;
+  ComplexMatrix solve (MatrixType &typ, const ComplexMatrix& b,
+                       octave_idx_type& info) const;
+  ComplexMatrix solve (MatrixType &typ, const ComplexMatrix& b,
+                       octave_idx_type& info, double& rcon) const;
+  ComplexMatrix solve (MatrixType &typ, const ComplexMatrix& b,
+                       octave_idx_type& info, double& rcon,
+                       solve_singularity_handler sing_handler,
+                       bool singular_fallback = true,
+                       blas_trans_type transt = blas_no_trans) const;
 
   ColumnVector solve (MatrixType &typ, const ColumnVector& b) const;
-  ColumnVector solve (MatrixType &typ, const ColumnVector& b, 
-		      octave_idx_type& info) const;
-  ColumnVector solve (MatrixType &typ, const ColumnVector& b, 
-		      octave_idx_type& info, double& rcond) const;
-  ColumnVector solve (MatrixType &typ, const ColumnVector& b, 
-		      octave_idx_type& info, double& rcond,
-		      solve_singularity_handler sing_handler) const;
+  ColumnVector solve (MatrixType &typ, const ColumnVector& b,
+                      octave_idx_type& info) const;
+  ColumnVector solve (MatrixType &typ, const ColumnVector& b,
+                      octave_idx_type& info, double& rcon) const;
+  ColumnVector solve (MatrixType &typ, const ColumnVector& b,
+                      octave_idx_type& info, double& rcon,
+                      solve_singularity_handler sing_handler,
+                      blas_trans_type transt = blas_no_trans) const;
 
-  ComplexColumnVector solve (MatrixType &typ, 
-			     const ComplexColumnVector& b) const;
-  ComplexColumnVector solve (MatrixType &typ, const ComplexColumnVector& b, 
-			     octave_idx_type& info) const;
-  ComplexColumnVector solve (MatrixType &typ, const ComplexColumnVector& b, 
-			     octave_idx_type& info, double& rcond) const;
-  ComplexColumnVector solve (MatrixType &typ, const ComplexColumnVector& b, 
-			     octave_idx_type& info, double& rcond,
-			     solve_singularity_handler sing_handler) const;
+  ComplexColumnVector solve (MatrixType &typ,
+                             const ComplexColumnVector& b) const;
+  ComplexColumnVector solve (MatrixType &typ, const ComplexColumnVector& b,
+                             octave_idx_type& info) const;
+  ComplexColumnVector solve (MatrixType &typ, const ComplexColumnVector& b,
+                             octave_idx_type& info, double& rcon) const;
+  ComplexColumnVector solve (MatrixType &typ, const ComplexColumnVector& b,
+                             octave_idx_type& info, double& rcon,
+                             solve_singularity_handler sing_handler,
+                             blas_trans_type transt = blas_no_trans) const;
 
   // Generic interface to solver with probing of type
   Matrix solve (const Matrix& b) const;
   Matrix solve (const Matrix& b, octave_idx_type& info) const;
-  Matrix solve (const Matrix& b, octave_idx_type& info, double& rcond) const;
-  Matrix solve (const Matrix& b, octave_idx_type& info, double& rcond,
-		solve_singularity_handler sing_handler) const;
+  Matrix solve (const Matrix& b, octave_idx_type& info, double& rcon) const;
+  Matrix solve (const Matrix& b, octave_idx_type& info, double& rcon,
+                solve_singularity_handler sing_handler,
+                blas_trans_type transt = blas_no_trans) const;
 
   ComplexMatrix solve (const ComplexMatrix& b) const;
   ComplexMatrix solve (const ComplexMatrix& b, octave_idx_type& info) const;
-  ComplexMatrix solve (const ComplexMatrix& b, octave_idx_type& info, double& rcond) const;
-  ComplexMatrix solve (const ComplexMatrix& b, octave_idx_type& info, double& rcond,
-		       solve_singularity_handler sing_handler) const;
+  ComplexMatrix solve (const ComplexMatrix& b, octave_idx_type& info, double& rcon) const;
+  ComplexMatrix solve (const ComplexMatrix& b, octave_idx_type& info, double& rcon,
+                       solve_singularity_handler sing_handler,
+                       blas_trans_type transt = blas_no_trans) const;
 
   ColumnVector solve (const ColumnVector& b) const;
   ColumnVector solve (const ColumnVector& b, octave_idx_type& info) const;
-  ColumnVector solve (const ColumnVector& b, octave_idx_type& info, double& rcond) const;
-  ColumnVector solve (const ColumnVector& b, octave_idx_type& info, double& rcond,
-		      solve_singularity_handler sing_handler) const;
+  ColumnVector solve (const ColumnVector& b, octave_idx_type& info, double& rcon) const;
+  ColumnVector solve (const ColumnVector& b, octave_idx_type& info, double& rcon,
+                      solve_singularity_handler sing_handler,
+                      blas_trans_type transt = blas_no_trans) const;
 
   ComplexColumnVector solve (const ComplexColumnVector& b) const;
   ComplexColumnVector solve (const ComplexColumnVector& b, octave_idx_type& info) const;
   ComplexColumnVector solve (const ComplexColumnVector& b, octave_idx_type& info,
-			     double& rcond) const;
+                             double& rcon) const;
   ComplexColumnVector solve (const ComplexColumnVector& b, octave_idx_type& info,
-			     double& rcond,
-			     solve_singularity_handler sing_handler) const;
+                             double& rcon, solve_singularity_handler sing_handler,
+                             blas_trans_type transt = blas_no_trans) const;
 
   // Singular solvers
   Matrix lssolve (const Matrix& b) const;
   Matrix lssolve (const Matrix& b, octave_idx_type& info) const;
-  Matrix lssolve (const Matrix& b, octave_idx_type& info, octave_idx_type& rank) const;
+  Matrix lssolve (const Matrix& b, octave_idx_type& info,
+                  octave_idx_type& rank) const;
+  Matrix lssolve (const Matrix& b, octave_idx_type& info,
+                  octave_idx_type& rank, double& rcon) const;
 
   ComplexMatrix lssolve (const ComplexMatrix& b) const;
   ComplexMatrix lssolve (const ComplexMatrix& b, octave_idx_type& info) const;
   ComplexMatrix lssolve (const ComplexMatrix& b, octave_idx_type& info,
-			 octave_idx_type& rank) const;
+                         octave_idx_type& rank) const;
+  ComplexMatrix lssolve (const ComplexMatrix& b, octave_idx_type& info,
+                         octave_idx_type& rank, double &rcon) const;
 
   ColumnVector lssolve (const ColumnVector& b) const;
   ColumnVector lssolve (const ColumnVector& b, octave_idx_type& info) const;
-  ColumnVector lssolve (const ColumnVector& b, octave_idx_type& info, octave_idx_type& rank) const;
+  ColumnVector lssolve (const ColumnVector& b, octave_idx_type& info,
+                        octave_idx_type& rank) const;
+  ColumnVector lssolve (const ColumnVector& b, octave_idx_type& info,
+                        octave_idx_type& rank, double& rcon) const;
 
   ComplexColumnVector lssolve (const ComplexColumnVector& b) const;
-  ComplexColumnVector lssolve (const ComplexColumnVector& b, octave_idx_type& info) const;
-  ComplexColumnVector lssolve (const ComplexColumnVector& b, octave_idx_type& info,
-			       octave_idx_type& rank) const;
-
-  Matrix expm (void) const;
+  ComplexColumnVector lssolve (const ComplexColumnVector& b,
+                               octave_idx_type& info) const;
+  ComplexColumnVector lssolve (const ComplexColumnVector& b,
+                               octave_idx_type& info,
+                               octave_idx_type& rank) const;
+  ComplexColumnVector lssolve (const ComplexColumnVector& b,
+                               octave_idx_type& info,
+                               octave_idx_type& rank, double& rcon) const;
 
   Matrix& operator += (const DiagMatrix& a);
   Matrix& operator -= (const DiagMatrix& a);
@@ -249,18 +295,14 @@ public:
 
   // other operations
 
-  Matrix map (d_d_Mapper f) const;
-  boolMatrix map (b_d_Mapper f) const;
-
-  Matrix& apply (d_d_Mapper f);
-
   bool any_element_is_negative (bool = false) const;
+  bool any_element_is_nan (void) const;
   bool any_element_is_inf_or_nan (void) const;
   bool any_element_not_one_or_zero (void) const;
   bool all_elements_are_int_or_inf_or_nan (void) const;
   bool all_integers (double& max_val, double& min_val) const;
   bool too_large_for_float (void) const;
- 
+
   boolMatrix all (int dim = -1) const;
   boolMatrix any (int dim = -1) const;
 
@@ -271,8 +313,7 @@ public:
   Matrix sumsq (int dim = -1) const;
   Matrix abs (void) const;
 
-  ColumnVector diag (void) const;
-  ColumnVector diag (octave_idx_type k) const;
+  Matrix diag (octave_idx_type k = 0) const;
 
   ColumnVector row_min (void) const;
   ColumnVector row_max (void) const;
@@ -292,10 +333,6 @@ public:
   friend OCTAVE_API std::istream& operator >> (std::istream& is, Matrix& a);
 
   static double resize_fill_value (void) { return 0; }
-
-private:
-
-  Matrix (double *d, octave_idx_type r, octave_idx_type c) : MArray2<double> (d, r, c) { }
 };
 
 // Publish externally used friend functions.
@@ -313,6 +350,10 @@ extern OCTAVE_API Matrix Givens (double, double);
 
 extern OCTAVE_API Matrix Sylvester (const Matrix&, const Matrix&, const Matrix&);
 
+extern OCTAVE_API Matrix xgemm (const Matrix& a, const Matrix& b,
+                                blas_trans_type transa = blas_no_trans,
+                                blas_trans_type transb = blas_no_trans);
+
 extern OCTAVE_API Matrix operator * (const Matrix& a, const Matrix& b);
 
 extern OCTAVE_API Matrix min (double d, const Matrix& m);
@@ -323,24 +364,22 @@ extern OCTAVE_API Matrix max (double d, const Matrix& m);
 extern OCTAVE_API Matrix max (const Matrix& m, double d);
 extern OCTAVE_API Matrix max (const Matrix& a, const Matrix& b);
 
-MS_CMP_OP_DECLS (Matrix, double)
-MS_BOOL_OP_DECLS (Matrix, double)
+extern OCTAVE_API Matrix linspace (const ColumnVector& x1,
+                                   const ColumnVector& x2,
+                                   octave_idx_type n);
 
-SM_CMP_OP_DECLS (double, Matrix)
-SM_BOOL_OP_DECLS (double, Matrix)
+MS_CMP_OP_DECLS (Matrix, double, OCTAVE_API)
+MS_BOOL_OP_DECLS (Matrix, double, OCTAVE_API)
 
-MM_CMP_OP_DECLS (Matrix, Matrix)
-MM_BOOL_OP_DECLS (Matrix, Matrix)
+SM_CMP_OP_DECLS (double, Matrix, OCTAVE_API)
+SM_BOOL_OP_DECLS (double, Matrix, OCTAVE_API)
 
-MARRAY_FORWARD_DEFS (MArray2, Matrix, double)
+MM_CMP_OP_DECLS (Matrix, Matrix, OCTAVE_API)
+MM_BOOL_OP_DECLS (Matrix, Matrix, OCTAVE_API)
+
+MARRAY_FORWARD_DEFS (MArray, Matrix, double)
 
 template <class T>
 void read_int (std::istream& is, bool swap_bytes, T& val);
 
 #endif
-
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
