@@ -18,7 +18,8 @@
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} fliplr (@var{x})
-## Return a copy of @var{x} with the order of the columns reversed.  For
+## Return a copy of @var{x} with the order of the columns reversed.  In
+## other words, @var{x} is flipped left-to-right about a vertical axis.  For
 ## example:
 ##
 ## @example
@@ -29,7 +30,7 @@
 ## @end group
 ## @end example
 ##
-## Note that @code{fliplr} only work with 2-D arrays.  To flip N-d arrays
+## Note that @code{fliplr} only works with 2-D arrays.  To flip N-D arrays
 ## use @code{flipdim} instead.
 ## @seealso{flipud, flipdim, rot90, rotdim}
 ## @end deftypefn
