@@ -1,5 +1,4 @@
-## Copyright (C) 1993, 1994, 1995, 1996, 1997, 1999, 2000, 2004, 2005,
-##               2006, 2007 John W. Eaton
+## Copyright (C) 1993-2011 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -18,11 +17,12 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} rot90 (@var{x}, @var{n})
-## Return a copy of @var{x} with the elements rotated counterclockwise in
+## @deftypefn  {Function File} {} rot90 (@var{A})
+## @deftypefnx {Function File} {} rot90 (@var{A}, @var{k})
+## Return a copy of @var{A} with the elements rotated counterclockwise in
 ## 90-degree increments.  The second argument is optional, and specifies
 ## how many 90-degree rotations are to be applied (the default value is 1).
-## Negative values of @var{n} rotate the matrix in a clockwise direction.
+## Negative values of @var{k} rotate the matrix in a clockwise direction.
 ## For example,
 ##
 ## @example
@@ -45,27 +45,26 @@
 ## @end group
 ## @end example
 ##
-## Due to the difficulty of defining an axis about which to rotate the 
-## matrix @code{rot90} only work with 2-D arrays.  To rotate N-d arrays
+## Note that @code{rot90} only works with 2-D arrays.  To rotate N-D arrays
 ## use @code{rotdim} instead.
 ## @seealso{rotdim, flipud, fliplr, flipdim}
 ## @end deftypefn
 
 ## Author: jwe
 
-function y = rot90 (x, k)
+function B = rot90 (A, k)
 
   if (nargin == 1 || nargin == 2)
     if (nargin < 2)
       k = 1;
     endif
 
-    if (ndims (x) > 2)
-      error ("rot90: Only works with 2-D arrays")
+    if (ndims (A) > 2)
+      error ("rot90: Only works with 2-D arrays");
     endif
 
     if (imag (k) != 0 || fix (k) != k)
-      error ("rot90: k must be an integer");
+      error ("rot90: K must be an integer");
     endif
 
     k = rem (k, 4);
@@ -75,13 +74,13 @@ function y = rot90 (x, k)
     endif
 
     if (k == 0)
-      y = x;
+      B = A;
     elseif (k == 1)
-      y = flipud (x.');
+      B = flipud (A.');
     elseif (k == 2)
-      y = flipud (fliplr (x));
+      B = flipud (fliplr (A));
     elseif (k == 3)
-      y = (flipud (x)).';
+      B = (flipud (A)).';
     else
       error ("rot90: internal error!");
     endif
@@ -90,3 +89,21 @@ function y = rot90 (x, k)
   endif
 
 endfunction
+
+%!test
+%! x1 = [1, 2; 3, 4];
+%! x2 = [2, 4; 1, 3];
+%! x3 = [4, 3; 2, 1];
+%! x4 = [3, 1; 4, 2];
+%!
+%! assert(rot90 (x1) == x2);
+%! assert(rot90 (x1, 2) == x3);
+%! assert(rot90 (x1, 3) == x4);
+%! assert(rot90 (x1, 4) == x1);
+%! assert(rot90 (x1, 5) == x2);
+%! assert(rot90 (x1, -1) == x4);
+
+%% Test input validation
+%!error rot90 ();
+%!error rot90 (1, 2, 3);
+
