@@ -20,7 +20,7 @@
 ## @deftypefn  {Function File} {@var{map_out} =} brighten (@var{map}, @var{beta})
 ## @deftypefnx {Function File} {@var{map_out} =} brighten (@var{h}, @var{beta})
 ## @deftypefnx {Function File} {@var{map_out} =} brighten (@var{beta})
-## Darkens or brightens the given colormap.  If the @var{map} argument
+## Darken or brighten the given colormap.  If the @var{map} argument
 ## is omitted, the function is applied to the current colormap.  The first
 ## argument can also be a valid graphics handle @var{h}, in which case
 ## @code{brighten} is applied to the colormap associated with this handle.
