@@ -1,4 +1,4 @@
-## Copyright (C) 1999, 2000, 2007, 2009 Kai Habel
+## Copyright (C) 1999-2011 Kai Habel
 ##
 ## This file is part of Octave.
 ##
@@ -17,33 +17,36 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} rainbow (@var{n})
-## Create color colormap.  This colormap is red through orange, yellow, green, 
-## blue to violet.  The argument @var{n} should be a scalar.  If it
-## is omitted, the length of the current colormap or 64 is assumed.
+## @deftypefn  {Function File} {@var{map} =} rainbow ()
+## @deftypefnx {Function File} {@var{map} =} rainbow (@var{n})
+## Create color colormap.  This colormap ranges from red through orange,
+## yellow, green, blue, to violet.
+## The argument @var{n} must be a scalar.
+## If unspecified, the length of the current colormap, or 64, is used.
 ## @seealso{colormap}
 ## @end deftypefn
 
 ## Author:  Kai Habel <kai.habel@gmx.de>
 
-function map = rainbow (number)
 ## this colormap is not part of matlab, it is like the prism
 ## colormap map but with a continuous map
 
+function map = rainbow (n)
+
   if (nargin == 0)
-    number = rows (colormap);
+    n = rows (colormap);
   elseif (nargin == 1)
-    if (! isscalar (number))
+    if (! isscalar (n))
       error ("rainbow: argument must be a scalar");
     endif
   else
     print_usage ();
   endif
 
-  if (number == 1)
-    map = [1, 0, 0];  
-  elseif (number > 1)
-    x = linspace (0, 1, number)';
+  if (n == 1)
+    map = [1, 0, 0];
+  elseif (n > 1)
+    x = linspace (0, 1, n)';
     r = (x < 2/5) + (x >= 2/5 & x < 3/5) .* (-5 * x + 3)\
       + (x >= 4/5) .* (10/3 * x - 8/3);
     g = (x < 2/5) .* (5/2 * x) + (x >= 2/5 & x < 3/5)\
@@ -55,3 +58,10 @@ function map = rainbow (number)
   endif
 
 endfunction
+
+%!demo
+%! ## Show the 'rainbow' colormap as an image
+%! image (1:64, linspace (0, 1, 64), repmat (1:64, 64, 1)')
+%! axis ([1, 64, 0, 1], "ticy", "xy")
+%! colormap (rainbow (64))
+
