@@ -20,9 +20,9 @@
 ## @deftypefn {Function File} {} gunzip (@var{gzfile}, @var{dir})
 ## Unpack the gzip archive @var{gzfile} to the directory @var{dir}.  If
 ## @var{dir} is not specified, it defaults to the current directory.  If
-## the @var{gzfile} is a directory, all gzfile in the directory will be
+## @var{gzfile} is a directory, all gzfiles in the directory will be
 ## recursively gunzipped.
-## @seealso{unpack, bunzip2, tar, untar, gzip, gunzip, zip, unzip}
+## @seealso{gzip, unpack, bunzip2, unzip, untar}
 ## @end deftypefn
 
 ## Author: Bill Denney <denney@seas.upenn.edu>
