@@ -1,5 +1,4 @@
-## Copyright (C) 1993, 1994, 1995, 1996, 1997, 1999, 2000, 2002, 2004,
-##               2005, 2006, 2007, 2008 John W. Eaton
+## Copyright (C) 1993-2011 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -18,16 +17,19 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} stairs (@var{x}, @var{y})
+## @deftypefn  {Function File} {} stairs (@var{y})
+## @deftypefnx {Function File} {} stairs (@var{x}, @var{y})
 ## @deftypefnx {Function File} {} stairs (@dots{}, @var{style})
 ## @deftypefnx {Function File} {} stairs (@dots{}, @var{prop}, @var{val})
 ## @deftypefnx {Function File} {} stairs (@var{h}, @dots{})
 ## @deftypefnx {Function File} {@var{h} =} stairs (@dots{})
+## @deftypefnx {Function File} {[@var{xstep}, @var{ystep}] =} stairs (@dots{})
 ## Produce a stairstep plot.  The arguments may be vectors or matrices.
 ##
 ## If only one argument is given, it is taken as a vector of y-values
 ## and the x coordinates are taken to be the indices of the elements.
 ##
+## If one output argument is requested, return a graphics handle to the plot.
 ## If two output arguments are specified, the data are generated but
 ## not plotted.  For example,
 ##
@@ -65,11 +67,11 @@ function [xs, ys] = stairs (varargin)
     else
       oldax = gca ();
       unwind_protect
-	axes (ax);
-	newplot ();
-	[h, xxs, yys] = __stairs__ (true, varargin{:});
+        axes (ax);
+        newplot ();
+        [h, xxs, yys] = __stairs__ (true, varargin{:});
       unwind_protect_cleanup
-	axes (oldax);
+        axes (oldax);
       end_unwind_protect
     endif
     if (nargout == 1)
@@ -80,12 +82,12 @@ endfunction
 
 function [h, xs, ys] = __stairs__ (doplot, varargin)
 
-  if (nargin == 1 || ischar (varargin{2}))
+  if (nargin == 2 || ischar (varargin{2}))
     y = varargin {1};
     varargin(1) = [];
     if (ismatrix (y))
       if (isvector (y))
-	y = y(:);
+        y = y(:);
       endif
       x = 1:rows (y);
     endif
@@ -116,7 +118,7 @@ function [h, xs, ys] = __stairs__ (doplot, varargin)
     else
       [x_nr, x_nc] = size (x);
       if (x_nr != nr || x_nc != nc)
-	error ("stairs: argument size mismatch");
+        error ("stairs: argument size mismatch");
       endif
     endif
   endif
@@ -143,59 +145,59 @@ function [h, xs, ys] = __stairs__ (doplot, varargin)
     if ((ischar (arg) || iscell (arg)) && ! have_line_spec)
       [linespec, valid] = __pltopt__ ("stairs", arg, false);
       if (valid)
-	have_line_spec = true;
-	varargin(i) = [];
-	break;
+        have_line_spec = true;
+        varargin(i) = [];
+        break;
       endif
     endif
-  endfor 
+  endfor
 
   if (doplot)
     h = [];
     unwind_protect
       hold_state = get (gca (), "nextplot");
       for i = 1 : size(y, 2)
-	hg = hggroup ();
-	h = [h; hg];
-	args = __add_datasource__ ("stairs", hg, {"x", "y"}, varargin{:});
+        hg = hggroup ();
+        h = [h; hg];
+        args = __add_datasource__ ("stairs", hg, {"x", "y"}, varargin{:});
 
-	addproperty ("xdata", hg, "data", x(:,i).');
-	addproperty ("ydata", hg, "data", y(:,i).');
+        addproperty ("xdata", hg, "data", x(:,i).');
+        addproperty ("ydata", hg, "data", y(:,i).');
 
-	addlistener (hg, "xdata", @update_data);
-	addlistener (hg, "ydata", @update_data);
+        addlistener (hg, "xdata", @update_data);
+        addlistener (hg, "ydata", @update_data);
 
-	if (have_line_spec)
-	  tmp = line (xs(:,i).', ys(:,i).', "color", linespec.color,
-		      "parent", hg);
-	else
-	  tmp = line (xs(:,i).', ys(:,i).', "color", __next_line_color__ (),
-		      "parent", hg);
-	endif
+        if (have_line_spec)
+          tmp = line (xs(:,i).', ys(:,i).', "color", linespec.color,
+                      "parent", hg);
+        else
+          tmp = line (xs(:,i).', ys(:,i).', "color", __next_line_color__ (),
+                      "parent", hg);
+        endif
 
         addproperty ("color", hg, "linecolor", get (tmp, "color"));
-	addproperty ("linewidth", hg, "linelinewidth", get (tmp, "linewidth"));
-	addproperty ("linestyle", hg, "linelinestyle", get (tmp, "linestyle"));
+        addproperty ("linewidth", hg, "linelinewidth", get (tmp, "linewidth"));
+        addproperty ("linestyle", hg, "linelinestyle", get (tmp, "linestyle"));
 
-	addproperty ("marker", hg, "linemarker", get (tmp, "marker"));
-	addproperty ("markerfacecolor", hg, "linemarkerfacecolor",
-		     get (tmp, "markerfacecolor"));
-	addproperty ("markeredgecolor", hg, "linemarkeredgecolor",
-		     get (tmp, "markeredgecolor"));
-	addproperty ("markersize", hg, "linemarkersize",
-		     get (tmp, "markersize"));
+        addproperty ("marker", hg, "linemarker", get (tmp, "marker"));
+        addproperty ("markerfacecolor", hg, "linemarkerfacecolor",
+                     get (tmp, "markerfacecolor"));
+        addproperty ("markeredgecolor", hg, "linemarkeredgecolor",
+                     get (tmp, "markeredgecolor"));
+        addproperty ("markersize", hg, "linemarkersize",
+                     get (tmp, "markersize"));
 
-	addlistener (hg, "color", @update_props);
-	addlistener (hg, "linewidth", @update_props); 
-	addlistener (hg, "linestyle", @update_props); 
-	addlistener (hg, "marker", @update_props); 
-	addlistener (hg, "markerfacecolor", @update_props); 
-	addlistener (hg, "markeredgecolor", @update_props); 
-	addlistener (hg, "markersize", @update_props); 
+        addlistener (hg, "color", @update_props);
+        addlistener (hg, "linewidth", @update_props);
+        addlistener (hg, "linestyle", @update_props);
+        addlistener (hg, "marker", @update_props);
+        addlistener (hg, "markerfacecolor", @update_props);
+        addlistener (hg, "markeredgecolor", @update_props);
+        addlistener (hg, "markersize", @update_props);
 
-	if (! isempty (args))
-	  set (hg, args{:});
-	endif
+        if (! isempty (args))
+          set (hg, args{:});
+        endif
       endfor
     unwind_protect_cleanup
       set (gca (), "nextplot", hold_state);
@@ -206,19 +208,30 @@ function [h, xs, ys] = __stairs__ (doplot, varargin)
 
 endfunction
 
+
 %!demo
 %! x = 1:10;
-%! y = rand (1, 10);
+%! rand_1x10_data1 = [0.073, 0.455, 0.837, 0.124, 0.426, 0.781, 0.004, 0.024, 0.519, 0.698];
+%! y = rand_1x10_data1;
 %! stairs (x, y);
 
 %!demo
 %! x = 1:10;
-%! y = rand (1, 10);
+%! rand_1x10_data2 = [0.014, 0.460, 0.622, 0.394, 0.531, 0.378, 0.466, 0.788, 0.342, 0.893];
+%! y = rand_1x10_data2;
 %! [xs, ys] = stairs (x, y);
 %! plot (xs, ys);
 
+%!demo
+%! stairs (1:9);
+
+%!demo
+%! [xs, ys] = stairs (9:-1:1);
+%! plot (xs, ys);
+
+
 function update_props (h, d)
-  set (get (h, "children"), "color", get (h, "color"), 
+  set (get (h, "children"), "color", get (h, "color"),
        "linewidth", get (h, "linewidth"),
        "linestyle", get (h, "linestyle"),
        "marker", get (h, "marker"),
