@@ -1,4 +1,4 @@
-## Copyright (C) 2000, 2005, 2006, 2007 Paul Kienzle
+## Copyright (C) 2000-2011 Paul Kienzle
 ##
 ## This file is part of Octave.
 ##
@@ -17,56 +17,63 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {@var{q} =} polygcd (@var{b}, @var{a}, @var{tol})
+## @deftypefn  {Function File} {@var{q} =} polygcd (@var{b}, @var{a})
+## @deftypefnx {Function File} {@var{q} =} polygcd (@var{b}, @var{a}, @var{tol})
 ##
-## Find greatest common divisor of two polynomials.  This is equivalent
+## Find the greatest common divisor of two polynomials.  This is equivalent
 ## to the polynomial found by multiplying together all the common roots.
 ## Together with deconv, you can reduce a ratio of two polynomials.
-## Tolerance defaults to 
-## @example 
-## sqrt(eps).
-## @end example
-##  Note that this is an unstable
-## algorithm, so don't try it on large polynomials.
+## Tolerance defaults to @code{sqrt(eps)}.
+##
+## Note that this is a numerically unstable algorithm, and should not be used
+## on large polynomials.
+##
+## Example:
 ##
-## Example
 ## @example
+## @group
 ## polygcd (poly(1:8), poly(3:12)) - poly(3:8)
 ## @result{} [ 0, 0, 0, 0, 0, 0, 0 ]
-## deconv (poly(1:8), polygcd (poly(1:8), poly(3:12))) - poly(1:2)
+## deconv (poly(1:8), polygcd (poly(1:8), poly(3:12))) ...
+##   - poly(1:2)
 ## @result{} [ 0, 0, 0 ]
+## @end group
 ## @end example
-## @seealso{poly, polyinteg, polyderiv, polyreduce, roots, conv, deconv,
-## residue, filter, polyval, and polyvalm}
+## @seealso{poly, polyint, polyderiv, polyreduce, roots, conv, deconv,
+## residue, filter, polyval, polyvalm}
 ## @end deftypefn
 
 function x = polygcd (b, a, tol)
 
   if (nargin == 2 || nargin == 3)
     if (nargin == 2)
-      tol = sqrt (eps);
+      if (isa (a, "single") || isa (b, "single"))
+        tol = sqrt (eps ("single"));
+      else
+        tol = sqrt (eps);
+      endif
     endif
     if (length (a) == 1 || length (b) == 1)
       if (a == 0)
-	x = b;
+        x = b;
       elseif (b == 0)
-	x = a;
+        x = a;
       else
-	x = 1;
+        x = 1;
       endif
     else
       a /= a(1);
       while (1)
-	[d, r] = deconv (b, a);
-	nz = find (abs (r) > tol);
-	if (isempty (nz))
-	  x = a;
-	  break;
-	else
-	  r = r(nz(1):length(r));
-	endif
-	b = a;
-	a = r / r(1);
+        [d, r] = deconv (b, a);
+        nz = find (abs (r) > tol);
+        if (isempty (nz))
+          x = a;
+          break;
+        else
+          r = r(nz(1):length(r));
+        endif
+        b = a;
+        a = r / r(1);
       endwhile
     endif
   else
