@@ -1,5 +1,4 @@
-## Copyright (C) 1994, 1995, 1996, 1997, 1999, 2000, 2004, 2005, 2006,
-##               2007, 2008 John W. Eaton
+## Copyright (C) 1994-2011 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -22,53 +21,52 @@
 ##
 ## For a vector @var{v} with @math{N} components, return
 ## the roots of the polynomial
-## @iftex
 ## @tex
 ## $$
 ## v_1 z^{N-1} + \cdots + v_{N-1} z + v_N.
 ## $$
 ## @end tex
-## @end iftex
 ## @ifnottex
 ##
 ## @example
-## v(1) * z^(N-1) + ... + v(N-1) * z + v(N)
+## v(1) * z^(N-1) + @dots{} + v(N-1) * z + v(N)
 ## @end example
+##
 ## @end ifnottex
 ##
 ## As an example, the following code finds the roots of the quadratic
 ## polynomial
-## @iftex
 ## @tex
 ## $$ p(x) = x^2 - 5. $$
 ## @end tex
-## @end iftex
 ## @ifnottex
+##
 ## @example
 ## p(x) = x^2 - 5.
 ## @end example
+##
 ## @end ifnottex
+##
 ## @example
+## @group
 ## c = [1, 0, -5];
 ## roots(c)
 ## @result{}  2.2361
 ## @result{} -2.2361
+## @end group
 ## @end example
+##
 ## Note that the true result is
-## @iftex
 ## @tex
 ## $\pm \sqrt{5}$
 ## @end tex
-## @end iftex
 ## @ifnottex
 ## @math{+/- sqrt(5)}
 ## @end ifnottex
 ## which is roughly
-## @iftex
 ## @tex
 ## $\pm 2.2361$.
 ## @end tex
-## @end iftex
 ## @ifnottex
 ## @math{+/- 2.2361}.
 ## @end ifnottex
@@ -84,7 +82,7 @@ function r = roots (v)
   if (nargin != 1 || min (size (v)) > 1)
     print_usage ();
   elseif (any (isnan(v) | isinf(v)))
-    error ("roots: inputs must not contain Inf or NaN")
+    error ("roots: inputs must not contain Inf or NaN");
   endif
 
   n = numel (v);
@@ -119,3 +117,25 @@ function r = roots (v)
   endif
 
 endfunction
+
+%!test
+%! p = [poly([3 3 3 3]), 0 0 0 0];
+%! r = sort (roots (p));
+%! assert (r, [0; 0; 0; 0; 3; 3; 3; 3], 0.001)
+
+%!assert(all (all (abs (roots ([1, -6, 11, -6]) - [3; 2; 1]) < sqrt (eps))));
+
+%!assert(isempty (roots ([])));
+
+%!error roots ([1, 2; 3, 4]);
+
+%!assert(isempty (roots (1)));
+
+%!error roots ([1, 2; 3, 4]);
+
+%!error roots ([1 Inf 1]);
+
+%!error roots ([1 NaN 1]);
+
+%!assert(roots ([1e-200, -1e200, 1]), 1e-200)
+%!assert(roots ([1e-200, -1e200 * 1i, 1]), -1e-200 * 1i)
