@@ -31,7 +31,7 @@
 ## The optional argument @var{dim} determines the dimension along which
 ## the quantiles are calculated.  If @var{dim} is omitted, and @var{x} is
 ## a vector or matrix, it defaults to 1 (column-wise quantiles).  If
-## @var{x} is an N-d array, @var{dim} defaults to the first non-singleton
+## @var{x} is an N-D array, @var{dim} defaults to the first non-singleton
 ## dimension.
 ##
 ## The methods available to calculate sample quantiles are the nine methods
@@ -87,6 +87,16 @@
 ## @item R: A Language and Environment for Statistical Computing;
 ## @url{http://cran.r-project.org/doc/manuals/fullrefman.pdf}.
 ## @end itemize
+##
+## Examples:
+##
+## @example
+## @group
+## x = randi (1000, [10, 1]);  # Create random empirical data in range 1-1000
+## q = quantile (x, [0, 1]);   # Return minimum, maximum of empirical distribution
+## q = quantile (x, [0.25 0.5 0.75]); # Return quartiles of empirical distribution
+## @end group
+## @end example
 ## @seealso{prctile}
 ## @end deftypefn
 
@@ -373,7 +383,7 @@ function inv = __quantile__ (x, p, method = 5)
             p = kron (p, m+0.25) + 0.375;
 
           otherwise
-            error ("quantile: Unknown method, '%d'", method);
+            error ("quantile: Unknown METHOD, '%d'", method);
         endswitch
 
         ## Duplicate single values.
