@@ -1,7 +1,6 @@
 /*
 
-Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007
-              John W. Eaton
+Copyright (C) 2000-2011 John W. Eaton
 
 This file is part of Octave.
 
@@ -24,9 +23,10 @@ along with Octave; see the file COPYING.  If not, see
 #if !defined (octave_c_file_ptr_stream_h)
 #define octave_c_file_ptr_stream_h 1
 
-#include <iostream>
 #include <cstdio>
 
+#include <iosfwd>
+
 class
 c_file_ptr_buf : public std::streambuf
 {
@@ -42,7 +42,7 @@ public:
 
   FILE* stdiofile (void) { return f; }
 
-  c_file_ptr_buf (FILE *f_arg, close_fcn cf_arg = fclose)
+  c_file_ptr_buf (FILE *f_arg, close_fcn cf_arg = file_close)
     : std::streambuf (), f (f_arg), cf (cf_arg)
     { }
 
@@ -61,27 +61,26 @@ public:
   std::streamsize xsgetn (char *, std::streamsize);
 
   std::streampos seekoff (std::streamoff, std::ios::seekdir,
-			  std::ios::openmode = std::ios::in | std::ios::out);
-  
+                          std::ios::openmode = std::ios::in | std::ios::out);
+
   std::streampos seekpos (std::streampos,
-			  std::ios::openmode = std::ios::in | std::ios::out);
+                          std::ios::openmode = std::ios::in | std::ios::out);
 
   int sync (void);
 
   int flush (void);
 
-  int close (void);
+  int buf_close (void);
 
   int file_number () const { return f ? fileno (f) : -1; }
 
-  int seek (long offset, int origin)
-    { return f ? fseek (f, offset, origin) : -1; }
+  int seek (long offset, int origin);
 
-  long tell (void) { return f ? ftell (f) : -1; }
+  long tell (void);
 
   void clear (void) { if (f) clearerr (f); }
 
-  static int fclose (FILE *f) { return ::fclose (f); }
+  static int file_close (FILE *f);
 
 protected:
 
@@ -92,6 +91,12 @@ protected:
 private:
 
   int_type underflow_common (bool);
+
+  // No copying!
+
+  c_file_ptr_buf (const c_file_ptr_buf&);
+
+  c_file_ptr_buf& operator = (const c_file_ptr_buf&);
 };
 
 // FIXME -- the following three classes could probably share
@@ -103,14 +108,14 @@ c_file_ptr_stream : public STREAM_T
 {
 public:
 
-  c_file_ptr_stream (FILE_T f, typename BUF_T::close_fcn cf = BUF_T::fclose)
+  c_file_ptr_stream (FILE_T f, typename BUF_T::close_fcn cf = BUF_T::file_close)
     : STREAM_T (0), buf (new BUF_T (f, cf)) { STREAM_T::init (buf); }
 
   ~c_file_ptr_stream (void) { delete buf; buf = 0; }
 
   BUF_T *rdbuf (void) { return buf; }
 
-  void close (void) { if (buf) buf->close (); }
+  void stream_close (void) { if (buf) buf->buf_close (); }
 
   int seek (long offset, int origin)
     { return buf ? buf->seek (offset, origin) : -1; }
@@ -122,6 +127,12 @@ public:
 private:
 
   BUF_T *buf;
+
+  // No copying!
+
+  c_file_ptr_stream (const c_file_ptr_stream&);
+
+  c_file_ptr_stream& operator = (const c_file_ptr_stream&);
 };
 
 typedef c_file_ptr_stream<std::istream, FILE *, c_file_ptr_buf> i_c_file_ptr_stream;
@@ -149,7 +160,7 @@ public:
 
   gzFile stdiofile (void) { return f; }
 
-  c_zfile_ptr_buf (gzFile f_arg, close_fcn cf_arg = fclose)
+  c_zfile_ptr_buf (gzFile f_arg, close_fcn cf_arg = file_close)
     : std::streambuf (), f (f_arg), cf (cf_arg)
     { }
 
@@ -168,16 +179,16 @@ public:
   std::streamsize xsgetn (char *, std::streamsize);
 
   std::streampos seekoff (std::streamoff, std::ios::seekdir,
-			  std::ios::openmode = std::ios::in | std::ios::out);
-  
+                          std::ios::openmode = std::ios::in | std::ios::out);
+
   std::streampos seekpos (std::streampos,
-			  std::ios::openmode = std::ios::in | std::ios::out);
+                          std::ios::openmode = std::ios::in | std::ios::out);
 
   int sync (void);
 
   int flush (void);
 
-  int close (void);
+  int buf_close (void);
 
   int file_number () const { return -1; }
 
@@ -188,7 +199,7 @@ public:
 
   void clear (void) { if (f) gzclearerr (f); }
 
-  static int fclose (gzFile f) { return ::gzclose (f); }
+  static int file_close (gzFile f) { return ::gzclose (f); }
 
 protected:
 
@@ -199,6 +210,12 @@ protected:
 private:
 
   int_type underflow_common (bool);
+
+  // No copying!
+
+  c_zfile_ptr_buf (const c_zfile_ptr_buf&);
+
+  c_zfile_ptr_buf& operator = (const c_zfile_ptr_buf&);
 };
 
 typedef c_file_ptr_stream<std::istream, gzFile, c_zfile_ptr_buf> i_c_zfile_ptr_stream;
@@ -208,9 +225,3 @@ typedef c_file_ptr_stream<std::iostream, gzFile, c_zfile_ptr_buf> io_c_zfile_ptr
 #endif
 
 #endif
-
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
