@@ -213,7 +213,7 @@ gnu_readline (const std::string& s, bool force_readline)
           FILE *stream = command_editor::get_output_stream ();
 
           gnulib::fputs (s.c_str (), stream);
-          fflush (stream);
+          gnulib::fflush (stream);
         }
 
       FILE *curr_stream = command_editor::get_input_stream ();
@@ -428,7 +428,7 @@ get_input_from_file (const std::string& name, int warn)
   FILE *instream = 0;
 
   if (name.length () > 0)
-    instream = fopen (name.c_str (), "rb");
+    instream = gnulib::fopen (name.c_str (), "rb");
 
   if (! instream && warn)
     warning ("%s: no such file or directory", name.c_str ());
