@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2009 Benjamin Lindner
+Copyright (C) 2009-2011 Benjamin Lindner
 
 This file is part of Octave.
 
@@ -36,9 +36,3 @@ extern OCTINTERP_API std::string
 read_until_newline (std::istream& is, bool keep_newline = false);
 
 #endif
-
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
