@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2008 VZLU Prague, a.s.
+Copyright (C) 2008-2011 VZLU Prague, a.s.
 
 This file is part of Octave.
 
@@ -25,11 +25,13 @@ along with Octave; see the file COPYING.  If not, see
 #if !defined (octave_xnorm_h)
 #define octave_xnorm_h 1
 
+#include "oct-norm.h"
+
 class octave_value;
 
-extern octave_value xnorm (const octave_value& x, const octave_value& p);
-extern octave_value xcolnorms (const octave_value& x, const octave_value& p);
-extern octave_value xrownorms (const octave_value& x, const octave_value& p);
-extern octave_value xfrobnorm (const octave_value& x);
+extern OCTINTERP_API octave_value xnorm (const octave_value& x, const octave_value& p);
+extern OCTINTERP_API octave_value xcolnorms (const octave_value& x, const octave_value& p);
+extern OCTINTERP_API octave_value xrownorms (const octave_value& x, const octave_value& p);
+extern OCTINTERP_API octave_value xfrobnorm (const octave_value& x);
 
 #endif
